==> qmatrix-1.1.0.src.tar.gz: qmatrix/config/config-sl700.h <==
/*
  Copyright (C) 2003  Taiga Yonekura, taiga@col.hi-ho.ne.jp

  For more information about this appliation please look at:
   http://www.pat.hi-ho.ne.jp/kyonekura

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef CONFIG_SL700_H
#define CONFIG_SL700_H

#define CONFIG_SL700

//
// Screen Size
//
#define SCREENW 640   
#define SCREENH 480

//
// Image Datas
//

#define TITLEIMAGE_DATA title_data_
#define SINGLEIMAGE_DATA singlemode_data_
#define VSIMAGE_DATA     vsmode_data_
#define BLOCK01IMAGE_DATA mat1_data_
#define BLOCK02IMAGE_DATA mat2_data_

#define RETRYIMAGE_DATA retry_data_
#define YESIMAGE_DATA   yes_data_
#define NOIMAGE_DATA    no_data_
#define BACKIMAGE_DATA    back_data_
#define THINKNOWIMAGE_DATA thinknow_data_
#define LOGO2IMAGE_DATA logo2_data_

#define WIN1IMAGE_DATA win1_data_
#define WIN2IMAGE_DATA win2_data_
#define YOUWINIMAGE_DATA youwin_data_
#define YOULOSTIMAGE_DATA youlost_data_

#define TAIGA01IMAGE_DATA  taiga01_100_data_
#define TAIGA02IMAGE_DATA  taiga02_100_data_
#define TAIGA04IMAGE_DATA  taiga04_100_data_

#define PEN01IMAGE_DATA    pen01_100_data_
#define PEN02IMAGE_DATA    pen02_100_data_
#define PEN04IMAGE_DATA    pen04_100_data_

#define TAKU01IMAGE_DATA   taku01_100_data_
#define TAKU02IMAGE_DATA   taku02_100_data_
#define TAKU04IMAGE_DATA   taku04_100_data_

#define P_ATTACKIMAGE_DATA preattack_data_
#define A_ATTACKIMAGE_DATA afterattack_data_ 
#define DRAWGAMEIMGAE_DATA draw_data_

#define SELECTMESSAGE_DATA selectmsg_data_
#define STARIMAGE_DATA     star_data_
#define LEVELIMAGE_DATA    level_data_
//
// Image Position
//
#define TITLE_POSX     150
#define TITLE_POSY      50
#define LOGO_POSX      130
#define LOGO_POSY       40
#define SINGLEBTN_POSX 250 
#define SINGLEBTN_POSY 240
#define VSBTN_POSX     270
#define VSBTN_POSY     290
#define COPYLIGT_POSX  110
#define COPYLIGT_POSY  380
#define MAN_POSX       170
#define MAN_POSY       100
#define COM_POSX       170
#define COM_POSY       100
#define WIN_POSX       220
#define WIN_POSY       100

#define RETRY_POSX     220
#define RETRY_POSY     100
#define YES_POSX       230
#define YES_POSY       170
#define NO_POSX        350
#define NO_POSY        170

#define MESSAGE_POSX    220
#define MESSAGE_POSY    100

#define PLAYERNUM_POSX 530
#define PLAYERNUM_POSY 10
#define WINNER_POSX    210
#define WINNER_POSY    100

//#define ENEMY_POSX     210
//#define ENEMY_POSY     330

#define TIME_POSX       20
#define TIME_POSY      330
#define TURN_POSX       20
#define TURN_POSY      380
#define TURN_NUM_POSX  110
#define TURN_NUM_POSY  380
#define TIME_NUM_POSX  110
#define TIME_NUM_POSY  330

//for select view
#define ENEMY_IMG_POSX  130
#define ENEMY1_IMG_POSY 100
#define ENEMY2_IMG_POSY 210
#define MESGIMG_POSX    130
#define MESGIMG_POSY     10
#define LEVEL_OFFSETX   130 
#define STARIMG_OFFSETY  10
#define STARIMG_OFFSETX  85

//
// Filed Config
//
#define BLOCK_SIZE      25   
#define BLOCK_OFFSET_X  20   
#define BLOCK_OFFSET_Y  20   
#define BLOCK_NUM_X     20   
#define BLOCK_NUM_Y     15

//
// Enemy 
//
#define ENEMY_POSX 530
#define ENEMY_POSY  20

#endif

==> qmatrix-1.2.0.src.tar.gz: qmatrix/config/config-sl700.h <==
/*
  Copyright (C) 2003  Taiga Yonekura, taiga@col.hi-ho.ne.jp

  For more information about this appliation please look at:
   http://www.pat.hi-ho.ne.jp/kyonekura

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef CONFIG_SL700_H
#define CONFIG_SL700_H

#define CONFIG_SL700

//
// Screen Size
//
#define SCREENW 640   
#define SCREENH 480

//
// Image Datas
//
#define BOOTLOGO_IMG_DATA   bootlogo_data_
#define TITLEIMAGE_DATA title_data_
#define SINGLEIMAGE_DATA singlemode_data_
#define VSIMAGE_DATA     vsmode_data_
#define BLOCK01IMAGE_DATA mat1_data_
#define BLOCK02IMAGE_DATA mat2_data_

#define RETRYIMAGE_DATA retry_data_
#define YESIMAGE_DATA   yes_data_
#define NOIMAGE_DATA    no_data_
#define BACKIMAGE_DATA    back_data_
#define THINKNOWIMAGE_DATA thinknow_data_
#define LOGO2IMAGE_DATA logo2_data_

#define WIN1IMAGE_DATA win1_data_
#define WIN2IMAGE_DATA win2_data_
#define YOUWINIMAGE_DATA youwin_data_
#define YOULOSTIMAGE_DATA youlost_data_

#define TAIGA01IMAGE_DATA  taiga01_100_data_
#define TAIGA02IMAGE_DATA  taiga02_100_data_
#define TAIGA04IMAGE_DATA  taiga04_100_data_

#define PEN01IMAGE_DATA    pen01_100_data_
#define PEN02IMAGE_DATA    pen02_100_data_
#define PEN04IMAGE_DATA    pen04_100_data_

#define TAKU01IMAGE_DATA   taku01_100_data_
#define TAKU02IMAGE_DATA   taku02_100_data_
#define TAKU04IMAGE_DATA   taku04_100_data_

#define P_ATTACKIMAGE_DATA preattack_data_
#define A_ATTACKIMAGE_DATA afterattack_data_ 
#define DRAWGAMEIMGAE_DATA draw_data_

#define SELECTMESSAGE_DATA selectmsg_data_
#define STARIMAGE_DATA     star_data_
#define LEVELIMAGE_DATA    level_data_
//
// Image Position
//
#define BOOT_LOGO_X 220
#define BOOT_LOGO_Y 200
#define BOOT_LOGOSTRING_X 280
#define BOOT_LOGOSTRING_Y 240

#define TITLE_POSX     150
#define TITLE_POSY      50
#define LOGO_POSX      130
#define LOGO_POSY       40
#define SINGLEBTN_POSX 250 
#define SINGLEBTN_POSY 240
#define VSBTN_POSX     270
#define VSBTN_POSY     290
#define COPYLIGT_POSX  110
#define COPYLIGT_POSY  380
#define MAN_POSX       170
#define MAN_POSY       100
#define COM_POSX       170
#define COM_POSY       100
#define WIN_POSX       220
#define WIN_POSY       100

#define RETRY_POSX     220
#define RETRY_POSY     100
#define YES_POSX       230
#define YES_POSY       170
#define NO_POSX        350
#define NO_POSY        170

#define MESSAGE_POSX    220
#define MESSAGE_POSY    100

#define PLAYERNUM_POSX 530
#define PLAYERNUM_POSY 10
#define WINNER_POSX    210
#define WINNER_POSY    100

#define TIME_POSX       20
#define TIME_POSY      330
#define TURN_POSX       20
#define TURN_POSY      380
#define TURN_NUM_POSX  110
#define TURN_NUM_POSY  380
#define TIME_NUM_POSX  110
#define TIME_NUM_POSY  330

//for select view
#define ENEMY_IMG_POSX  130
#define ENEMY1_IMG_POSY 100
#define ENEMY2_IMG_POSY 210
#define ENEMY3_IMG_POSY 320
#define MESGIMG_POSX    130
#define MESGIMG_POSY     10
#define LEVEL_OFFSETX   130 
#define STARIMG_OFFSETY  10
#define STARIMG_OFFSETX  85
#define RESULT_WIN_OFFSETY  60
#define RESULT_LOST_OFFSETY 80

//
// Filed Config
//
#define BLOCK_SIZE      25   
#define BLOCK_OFFSET_X  20   
#define BLOCK_OFFSET_Y  20   
#define BLOCK_NUM_X     20   
#define BLOCK_NUM_Y     15

//
// Enemy 
//
#define ENEMY_POSX 530
#define ENEMY_POSY  20

#define BOOT_LOGOSTRING "PRESENTS"

#endif
